function to launch the ShinyApp Arena Analytics. This app helps users to explore their data from OpenForis Arena, gain insights and develop report-ready figures and statistics.
Examples
if (interactive()) {
shiny_run_arenalytics()
}
function to launch the ShinyApp Arena Analytics. This app helps users to explore their data from OpenForis Arena, gain insights and develop report-ready figures and statistics.
if (interactive()) {
shiny_run_arenalytics()
}